/*
 * Licensed to ElasticSearch and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. ElasticSearch licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.functionscore.exp;

import org.apache.lucene.search.ComplexExplanation;
import org.apache.lucene.search.Explanation;
import org.elasticsearch.index.query.functionscore.DecayFunction;
import org.elasticsearch.index.query.functionscore.DecayFunctionParser;

public class ExponentialDecayFunctionParser extends DecayFunctionParser {

    public static final String[] NAMES = { "exp" };

    @Override
    public String[] getNames() {
        return NAMES;
    }

    static final DecayFunction decayFunction = new ExponentialDecayScoreFunction();

    @Override
    public DecayFunction getDecayFunction() {
        return decayFunction;
    }

    final static class ExponentialDecayScoreFunction implements DecayFunction {

        @Override
        public double evaluate(double value, double scale) {
            return Math.exp(scale * value);
        }

        @Override
        public Explanation explainFunction(String valueExpl, double value, double scale) {
            ComplexExplanation ce = new ComplexExplanation();
            ce.setValue((float) evaluate(value, scale));
            ce.setDescription("exp(- abs(" + valueExpl + ") * " + -1 * scale + ")");
            return ce;
        }

        @Override
        public double processScale(double scale, double decay) {
            return Math.log(decay) / scale;
        }

    }
}
